#
# spec file for package python-flake8
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flake8
Version:        6.1.0
Release:        1.1
Summary:        Modular source code checker: pep8, pyflakes and co
License:        MIT
URL:            https://flake8.pycqa.org
Source:         https://github.com/PyCQA/flake8/archive/refs/tags/%{version}.tar.gz#/flake8-%{version}.tar.gz
# workaround for https://github.com/PyCQA/flake8/pull/1669
Source2:        https://raw.githubusercontent.com/PyCQA/flake8/%{version}/bin/gen-pycodestyle-plugin
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module mccabe >= 0.7.0 with %python-mccabe < 0.8.0}
BuildRequires:  %{python_module pycodestyle >= 2.11.0 with %python-pycodestyle < 2.12.0}
BuildRequires:  %{python_module pyflakes >= 3.1.0 with %python-pyflakes < 3.2.0}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildArch:      noarch
# https://flake8.pycqa.org/en/latest/faq.html#why-does-flake8-use-ranges-for-its-dependencies
Requires:       (python-mccabe >= 0.7.0 with python-mccabe < 0.8.0)
Requires:       (python-pycodestyle >= 2.11.0 with python-pycodestyle < 2.12.0)
Requires:       (python-pyflakes >= 3.1.0 with python-pyflakes < 3.2.0)
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
Flake8 is a modular extensible source code checker including wrappers
around these tools:

- PyFlakes
- pep8
- Ned Batchelder's McCabe script

Flake8 runs all the tools by launching the single ``flake8`` script.

%package -n %{name}-doc
Summary:        Documentation files for %{name}
Recommends:     %{name} = %{version}

%description -n %{name}-doc
Flake8 is a modular extensible source code checker.

This package provides documentation for %{name}.

%prep
%autosetup -p1 -n flake8-%{version}
install -m 0755 -D %{SOURCE2} bin/gen-pycodestyle-plugin

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/flake8
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative flake8

%postun
%python_uninstall_alternative flake8

%check
%pytest tests

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/flake8
%{python_sitelib}/flake8
%{python_sitelib}/flake8-%{version}.dist-info

%files -n %{name}-doc
%doc README.rst
%doc docs/source/index.rst docs/source/faq.rst docs/source/glossary.rst
%doc docs/source/internal/ docs/source/user docs/source/plugin-development
%license LICENSE

%changelog
* Tue Aug  8 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.1.0:
  * Pyflakes has been updated to >= 3.1.0, < 3.2.0 (See also #1847).
  * pycodestyle has been updated to >= 2.11.0, < 2.12.0 (See also #1848).
  * Deprecate --include-in-doctest, --exclude-from-doctest
  (See also #1747, #1768).
  * Add support for python 3.12 (See also #1832, #1849, #1850).
- Switch to pyproject macros.
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu Dec 15 2022 Dirk Müller <dmueller@suse.com>
- update to 6.0.0 (bsc#1206225):
  * https://flake8.pycqa.org/en/latest/release-notes/6.0.0.html
  * Require python >= 3.8.1 (See also #1633, #1741).
  * List available formatters in for --format option in --help (See also #223, #1624).
  * Improve multiprocessing performance (See also #1723).
  * Enable multiprocessing on non-fork platforms (See also #1723).
  * Ensure results are sorted when discovered from files (See also #1670, #1726).
* Sat Aug 27 2022 Ben Greiner <code@bnavigator.de>
- Pin to upstream's ranges in dependendcies in order to not break
  downstream packages all the time
  https://flake8.pycqa.org/en/latest/faq.html#why-does-flake8-use-ranges-for-its-dependencies
- Remove obsolete python2 packaging directives
* Thu Aug 18 2022 Dirk Müller <dmueller@suse.com>
- update to 5.0.4:
  * Remove ``indent_size_str`` (See also :pull:`1411`).
  * Remove some dead code (See also :pull:`1453`, :pull:`1540`, :pull:`1541`).
  * Missing explicitly-specified configuration is now an error (See also
  :issue:`1497`, :pull:`1498`).
  * Always read configuration files as UTF-8 (See also :issue:`1532`,
  :pull:`1533`).
  * Remove manpage from docs -- use ``help2man`` or related tools instead (See
  also :pull:`1557`).
  * Forbid invalid plugin codes (See also :issue:`325`, :pull:`1579`).
  * lots of bugfixes, see included changelog
- drop fix-mock-patch-with-python3.4.patch fix-recent-flake8-stdoutWriteHook-change.patch (obsolete/upstream)
* Thu Mar 17 2022 pgajdos@suse.com
- python-mock is actually not needed for build
* Sun Nov 14 2021 Martin Liška <mliska@suse.cz>
- Add temporarily workaround for https://github.com/tholo/pytest-flake8/issues/81
  (fix-recent-flake8-stdoutWriteHook-change.patch).
* Tue Nov  9 2021 Martin Liška <mliska@suse.cz>
- update to 4.0.1:
  * Update spec python module dependencies accordingly.
  * Fix parallel execution collecting a SyntaxError (See also #1410 #1408).
- update to 4.0.0:
  * Remove --install-hook vcs integration (See also #1008).
  * Remove setuptools command (See also #1009).
  * Migrate from GitLab to GitHub (See also #1305).
  * Due to constant confusion by users, user-level |Flake8| configuration files
    are no longer supported. Files will not be searched for in the user's home
    directory (e.g., ~/.flake8) nor in the XDG config directory (e.g.,
    ~/.config/flake8).  (See also #1404).
  * pycodestyle has been updated to >= 2.8.0, < 2.9.0 (See also #1406).
  * Pyflakes has been updated to >= 2.4.0, < 2.5.0 (See also #1406).
  * flake8 requires python >= 3.6 (See also #1010).
  * Add --extend-select option (See also #1312 #1061).
  * Automatically create directories for output files (See also #1329).
  * ast parse before tokenizing to improve SyntaxError errors (See also
    [#1320] #740).
  * Fix warning in --indent-size argparse help (See also #1367).
  * Fix handling SyntaxError in python 3.10+ (See also #1374
    [#1372]).
  * Fix writing non-cp1252-encodable when output is piped on windows (See also
    [#1382] #1381).
- Rebase fix-mock-patch-with-python3.4.patch and remove ignore-selectable-groups-warning.patch.
* Fri Sep 24 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add ignore-selectable-groups-warning.patch:
  * Ignore unfixed warning.
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 3.9.2:
  * Fix codes being ignored by plugins utilizing ``extend_default_ignore``
  * Fix error message for ``E111`` in ``pycodestyle``
  * ``indent_size_str`` is deprecated, use ``str(indent_size)`` instead
* Tue Mar 16 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v3.9.0
  * Pyflakes has been updated to >= 2.3.0
  * pycodestyle has been updated to >= 2.7.0
  * Drop support for python 3.4
  * Add --no-show-source option to disable --show-source
  * Fix handling of crlf line endings when linting stdin
* Sat Oct 10 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update patch lines numbers
  * removed pytest6.patch (included upstream)
- update to version 3.8.4:
  * Fix multiprocessing errors on platforms without sem_open syscall.
    (See also GitLab!448)
  * Fix skipping of physical checks on the last line of a file which
    does not end in a newline (See also GitLab!451)
* Mon Aug 31 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with pytest 6:
  * pytest6.patch
* Sat Jul 11 2020 Arun Persaud <arun@gmx.de>
- update to version 3.8.3:
  * Also catch SyntaxError when tokenizing (See also GitLab!433,
    GitLab#662)
  * Fix --jobs default display in flake8 --help (See also GitLab!434,
    GitLab#665)
* Wed Jun  3 2020 Arun Persaud <arun@gmx.de>
- update to version 3.8.2:
  * Improve performance by eliminating unncessary sort (See also
    GitLab!429)
  * Improve messaging of --jobs argument by utilizing argparse (See
    also GitLab!428, GitLab#567)
  * Fix file configuration options to be relative to the config passed
    on the command line (See also GitLab!431, GitLab#651)
  * Fix incorrect handling of --extend-exclude by treating its values
    as files (See also GitLab!432, GitLab#653)
* Thu May 14 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 3.8.1
  * Fix --output-file (regression in 3.8.0) (See also GitLab!427,
    GitLab#637)
- Update notes for 3.8.0
  * Fix logical checks which report positions out of bounds (See also
    GitLab!422, GitLab#635)
  * Fix --exclude=.* accidentally matching . and .. (See also GitLab!424,
    GitLab#632)
  * Add deprecation message for vcs hooks (See also GitLab!420, GitLab#568)
- Update notes for 3.8.0a2
  * Fix type="str" optparse options (See also GitLab!419)
- Update notes for 3.8.0a1
  New Dependency Information
  * Remove dependency on entrypoints and add dependency on importlib-metadata
    (only for python<3.8) (See also GitLab!388, GitLab#569)
  * Pyflakes has been updated to >= 2.2.0, < 2.3.0 (See also GitLab!417)
  * pycodestyle has been updated to >= 2.6.0a1, < 2.7.0 (See also GitLab!418)
  Features
  * Add --extend-exclude option to add to --exclude without overwriting (See
    also GitLab!315, GitLab#535)
  * Move argument parsing from optparse to argparse (See also GitLab!341
  * Group plugin options in --help (See also GitLab!342, GitLab#565)
  * Remove parsing of verbose from configuration files as it was not
    consistently applied (See also GitLab!360, GitLab#439)
  * Remove parsing of output_file from configuration files as it was not
    consistently applied (See also GitLab!361)
  * Resolve configuration files relative to cwd instead of common prefix of
    passed filenames. You may need to change flake8 subproject to cd subproject
    && flake8 . (See also GitLab!363)
  * Officially support python3.8 (See also GitLab!377)
  * --disable-noqa now also disables # flake8: noqa (See also GitLab!380,
    GitLab#590)
  * Ensure that a missing file produces a E902 error (See also GitLab!404,
    GitLab#600)
  * # noqa comments now apply to all of the lines in an explicit \ continuation
    or in a line continued by a multi-line string (See also GitLab!413, GitLab#375)
  Bugs Fixed
  * Fix --exclude=./t.py to only match t.py at the top level (See also
    GitLab!311, GitLab#382)
  * Fix --show-source when a file is indented with tabs (See also GitLab!339,
    GitLab#563)
  * Fix crash when --max-line-length is given a non-integer (See also
    GitLab!341, GitLab#541)
  * Prevent flip-flopping of indent_char causing extra E101 errors (See also
    GitLab!357, pycodestyle#886)
  * Only enable multiprocessing when the method is fork fixing issues on macos
    with python3.8+ (See also GitLab!366, GitLab#587) (note: this fix also
    landed in 3.7.9)
  * noqa is now only handled by flake8 fixing specific-noqa. Plugins requesting
    this parameter will always receive False (See also GitLab!331, GitLab#552)
  * Fix duplicate loading of plugins when invoked via python -m flake8 (See also
    GitLab!388)
  * Fix early exit when --exit-zero and --diff are provided and the diff is
    empty (See also GitLab!391)
  * Consistently split lines when \f is present when reading from stdin
    (See also GitLab!406, GitLab#270)
  Deprecations
  * python setup.py flake8 (setuptools integration) is now deprecated and will
    be removed in a future version (See also GitLab!330, GitLab#544)
  * type='string' (optparse) types are deprecated, use type=callable (argparse)
    instead. Support for type='string' will be removed in a future version (See
    also GitLab!341)
  * %%default in plugin option help text is deprecated, use %%(default)s instead.
    Support for %%default will be removed in a future version (See also
    GitLab!341)
  * optparse-style action='callback' setting for options is deprecated,
    use argparse action classes instead. This will be removed in a future
    version (See also GitLab!341)
- remove remove_mock_dependency.patch
- remove pyflakes-version.patch
* Mon May  4 2020 Matej Cepl <mcepl@suse.com>
- Skip failing test_all_pyflakes_messages_have_flake8_codes_assigned test
  (gl#pycqa/flake8#633)
- Add pyflakes-version.patch to make the package work with
  the pyflakes in Factory now.
* Wed Nov 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.7.9:
  * Disable multiprocessing when the multiprocessing method is spawn
    (such as on macos in python3.8) (See also GitLab!367, GitLab#587)
* Fri Jul 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.7.8:
  * Fix handling of Application.parse_preliminary_options_and_args when
    argv is an empty list (See also GitLab!310, GitLab#518)
  * Fix crash when a file parses but fails to tokenize (See also GitLab!314,
    GitLab#532)
  * Log the full traceback on plugin exceptions (See also GitLab!317)
  * Fix # noqa: ... comments with multi-letter codes (See also GitLab!326,
    GitLab#549)
- Rebase remove_mock_dependency.patch
* Sun Mar  3 2019 John Vandenberg <jayvdb@gmail.com>
- Create doc sub package with rst files, and README.rst
- Replace main package %%doc README.rst with manpage.rst
- Simplify dependency on python-typing, which is provided by
  python3-base when it isnt a separate dependency
* Sat Mar  2 2019 Arun Persaud <arun@gmx.de>
- update to version 3.7.7:
  * Fix crahes in plugins causing flake8 to hang while unpickling
    errors (See also GitLab!308, GitLab#505)
* Thu Feb 21 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v3.7.6
  * Fix ``--per-file-ignores`` for multi-letter error codes
  * Improve flake8 speed when only 1 filename is passed
* Wed Feb  6 2019 Antonio Larrosa <alarrosa@suse.com>
- Add missing dependency on python3-typing when python3 < 3.5
- Add fix-mock-patch-with-python3.4.patch to fix building the package in
  Leap 42.3. In python 3.5, mock.patch uses create=True automatically if
  you are patching builtins in a module, but in python 3.4 the argument
  is still needed.
* Tue Feb  5 2019 Antonio Larrosa <alarrosa@suse.com>
- Enable tests
- Add allow-bytes-filenames.patch to fix some tests that fail because
  they pass bytes objects as filenames.
- Update remove_mock_dependency.patch to fix another test that used mock
* Tue Feb  5 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 3.7.5:
  * Bugs Fixed
    + Fix reporting of pyflakes "referenced before assignment" error
    (See also GitLab!301, GitLab#503)
- Update to version 3.7.4:
  * Bugs Fixed
    + Fix performance regression with lots of per-file-ignores and errors
    (See also GitLab!299, GitLab#501)
- Update to version 3.7.3:
  * Bugs Fixed
    + Fix imports of typing in python 3.5.0 / 3.5.1 (See also GitLab!294,
    GitLab#498)
    + Fix flake8 --statistics (See also GitLab!295, GitLab#499)
    + Gracefully ignore flake8-per-file-ignores plugin if installed
    (See also GitLab!297, GitLab#495)
    + Improve error message for malformed per-file-ignores
    (See also GitLab!298, GitLab#489)
- Update to version 3.7.2:
  * Bugs Fixed
    + Fix broken flake8 --diff (regressed in 3.7.0) (See also GitLab!292,
    GitLab#490)
    + Fix typo in plugin exception reporting (See also GitLab!275, GitLab#491)
    + Fix AttributeError while attempting to use the legacy api
    (regressed in 3.7.0) (See also GitLab!293, GitLab#497)
- Update to version 3.7.1:
  * Bugs Fixed
    + Fix capitalized filenames in per-file-ignores setting (See also GitLab!290, GitLab#488)
- Update to version 3.7.0:
  * New Dependency Information
    + Add dependency on entrypoints >= 0.3, < 0.4
    (See also GitLab!264, GitLab!288)
    + Pyflakes has been updated to >= 2.1.0, < 2.2.0
    (See also GitLab!283, GitLab!285)
    + pycodestyle has been updated to >= 2.5.0, < 2.6.0
    (See also GitLab!287)
  * Features
    + Add support for per-file-ignores (See also GitLab!259, GitLab#156,
    GitLab!281, GitLab#471)
    + Enable use of float and complex option types (See also GitLab!261,
    GitLab#452)
    + Improve startup performance by switching from pkg_resources to
    entrypoints (See also GitLab!264)
    + Add metadata for use through the pre-commit git hooks framework
    (See also GitLab!268, GitLab!284)
    + Allow physical line checks to return more than one result
    (See also GitLab!269)
    + Allow # noqa:X123 comments without space between the colon and codes list
    (See also GitLab!273, GitLab#470)
    + Remove broken and unused flake8.listen plugin type
    (See also GitLab!274, GitLab#480)
- Remove pyflakes21.patch which is already included upstream
- Rebase remove_mock_dependency.patch
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with pyflakes-2.1.0:
  * pyflakes21.patch
* Thu Nov  1 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
  * remove two patches that got included upstream:
    + fix_pycodestyle_240.patch
    + python-flake8-3.5.0-pyflakes-2.0.0.patch
- update to version 3.6.0:
  * New Dependency Information
    + pycodestyle has been updated to >= 2.4.0, < 2.5.0 (See also
    GitLab#381, GitLab#415, GitLab!212, GitLab!230, GitLab!231)
    + Pyflakes has been updated to >= 2.0.0, < 2.1.0 (See also
    GitLab#422, GitLab!239)
    + flake8 requires python 2.x >= 2.7 or python 3.x >= 3.4 (See also
    GitLab!225)
  * Features
    + Add paths to allow local plugins to exist outside of sys.path
    (See also GitLab#379, GitLab!211)
    + Copy setup.cfg files to the temporary git hook execution
    directory (See also GitLab!215)
    + Only skip a file if # flake8: noqa is on a line by itself (See
    also GitLab#453, GitLab!219)
    + Provide a better user experience for broken plugins (See also
    GitLab!221)
    + Report E902 when a file passed on the command line does not
    exist (See also GitLab#405, GitLab!227)
    + Add --extend-ignore for extending the default ignore instead of
    overriding it (See also GitLab#365, GitLab!233)
  * Bugs Fixed
    + Respect a formatter's newline setting when printing (See also
    GitLab!222)
    + Fix leaking of processes in the legacy api (See also GitLab#410,
    GitLab!228)
    + Fix a SyntaxWarning for an invalid escape sequence (See also
    GitLab!244)
    + Fix DeprecationWarning due to import of abc classes from the
    collections module (See also GitLab!249)
    + Defer setuptools import to improve flake8 startup time (See also
    GitLab!250)
    + Fix inconsistent line endings in FileProcessor.lines when
    running under python 3.x (See also GitLab#457, GitLab!255)
* Wed Sep  5 2018 Matěj Cepl <mcepl@suse.com>
- Add remove_mock_dependency.patch patch providing independence from the
  external mock package.
* Wed Aug  8 2018 tchvatal@suse.com
- Add patch to build with pyflakes-2.0.x:
  * python-flake8-3.5.0-pyflakes-2.0.0.patch
* Sun Apr 15 2018 sebix+novell.com@sebix.at
- add fix_pycodestyle_240.patch to fix compatibility with pycodestyle
  version 2.4.0. fixes boo#1089438
- use %%license macro for license file
* Thu Jan 11 2018 tchvatal@suse.com
- Fix build with python3 only, add condition for the py2 only deps
* Tue Oct 24 2017 dmueller@suse.com
- update to 3.5.0:
  - Start using new PyCodestyle checks for bare excepts and ambiguous identifier
  drop 0001-Update-pyflakes-range-and-include-doc-links.patch: upstream
* Wed Oct 18 2017 alarrosa@suse.com
- update to 3.4.1
- Add 0001-Update-pyflakes-range-and-include-doc-links.patch from upstream
  in order to allow using pyflakes >= 1.6.0
* Fri Mar 24 2017 jmatejek@suse.com
- update for singlespec
- update to 3.3.0
  * fix setuptools integration
  * drop python 2.6 and python < 3.4 support
  * nonzero exit on problems
  * python 3.6 support
  * performance improvements
- switch requirement from pep8 to pycodestyle
- switch test runner from nose to pytest
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Jan 13 2016 toddrme2178@gmail.com
- Update to 2.5.1
  * Bug Properly look for .flake8 in current working directory
  * Bug Monkey-patch pep8.stdin_get_value to cache the actual value
    in stdin. This helps plugins relying on the function when run
    with multiprocessing.
- Update to 2.5.0
  * Improvement Raise cap on PyFlakes for Python 3.5 support
  * Improvement Avoid deprecation warnings when loading extensions
  * Improvement Separate logic to enable “off-by-default” extensions
  * Bug Properly parse options to setuptools Flake8 command
  * Bug Fix exceptions when output on stdout is truncated before
    Flake8 finishes writing the output
  * Bug Fix error on OS X where Flake8 can no longer acquire or
    create new semaphores
- Update to 2.4.1
  * Bug Do not raise a SystemError unless there were errors in the
    setuptools command.
  * Bug Do not verify dependencies of extensions loaded via
    entry-points.
  * Improvement Blacklist versions of pep8 we know are broken
- Update to 2.4.0
  * Bug Print filenames when using multiprocessing and -q option.
  * Bug Put upper cap on dependencies. The caps for 2.4.0 are:
    > pep8 < 1.6 (Related to GitLab#35)
    > mccabe < 0.4
    > pyflakes < 0.9
  * See also GitLab#32
  * Bug Files excluded in a config file were not being excluded
    when flake8 was run from a git hook.
  * Improvement Print warnings for users who are providing
    mutually exclusive options to flake8.
  * Feature Allow git hook configuration to live in .git/config.
    See the updated VCS hooks docs for more details.
- Remove upstream-included flake8-fix-tests-using-new-mock.patch
- Implement update-alternatives
* Mon Aug 10 2015 mlin@suse.com
- Add upstream patch flake8-fix-tests-using-new-mock.patch
  * Fix tests using mock 1.1.x and above
* Thu Feb 26 2015 tbechtold@suse.com
- update to 2.3.0
  - Add ``--output-file`` option to specify a file to write to
    instead of ``stdout``.
  - Fix interleaving of output while using multiprocessing
  - Flush standard out when using multiprocessing
  - Make the check for "# flake8: noqa" more strict
  - Fix bugs triggered by turning multiprocessing on by default (again)
  - Passing something in via stdin
  - Analyzing a diff
  - Using windows
  - Fix --install-hook when there are no config files present for pep8 or
    flake8.
  - Fix how the setuptools command parses excludes in config files
  - Fix how the git hook determines which files to analyze (Thanks Chris
    Buccella!)
* Mon Sep 15 2014 tbechtold@suse.com
- update to 2.2.3:
  * Actually turn multiprocessing on by default
- Update Requires for pyflakes, pep8 and mccabe
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 2.2.2
  - Re-enable multiprocessing by default while fixing the issue
    Windows users were seeing.
- Update to 2.2.1
  - Turn off multiple jobs by default. To enable automatic use
    of all CPUs, use --jobs=auto. Fixes #155 and #154.
* Fri Jun 27 2014 dmueller@suse.com
- update to 2.2.0:
  - New option ``doctests`` to run Pyflakes checks on doctests too
  - New option ``jobs`` to launch multiple jobs in parallel
  - Turn on using multiple jobs by default using the CPU count
  - Add support for ``python -m flake8`` on Python 2.7 and Python 3
  - Fix Git and Mercurial hooks: issues #88, #133, #148 and #149
  - Fix crashes with Python 3.4 by upgrading dependencies
  - Fix traceback when running tests with Python 2.6
  - Fix the setuptools command ``python setup.py flake8`` to read
    the project configuration
* Mon Jan 13 2014 dmueller@suse.com
- update to 2.1.0:
  - Add FLAKE8_LAZY and FLAKE8_IGNORE environment variable support to git and
    mercurial hooks
  - Force git and mercurial hooks to repsect configuration in setup.cfg
  - Only check staged files if that is specified
  - Fix hook file permissions
  - Fix the git hook on python 3
  - Ignore non-python files when running the git hook
  - Ignore .tox directories by default
  - Flake8 now reports the column number for PyFlakes messages
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Apr 24 2013 speilicke@suse.com
- Spec file cleanup
- Run testsuite
- Add LICENSE (for legal)
* Sun Apr 21 2013 dmueller@suse.com
- Initial package (2.0)
